============
protobuf-gen
============

.. image:: https://img.shields.io/pypi/v/protobuf-gen.svg
        :target: https://pypi.python.org/pypi/protobuf-gen

.. image:: https://img.shields.io/travis/andreycizov/python-protobuf-gen.svg
        :target: https://travis-ci.org/andreycizov/python-protobuf-gen

.. image:: https://readthedocs.org/projects/protobuf-gen/badge/?version=latest
        :target: https://protobuf-gen.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/andreycizov/python-protobuf-gen/shield.svg
        :target: https://pyup.io/repos/github/andreycizov/python-protobuf-gen/
        :alt: Updates

.. image:: https://codecov.io/gh/andreycizov/python-protobuf-gen/coverage.svg?branch=master
        :target: https://codecov.io/gh/andreycizov/python-protobuf-gen/?branch=master


Show some info here

Basic usage:

.. code-block:: python

    # show some examples here.